@@ -19,7 +19,10 @@ group :test do
 	gem "sus", "~> 0.15"
 	gem "covered"
 	gem "decode"
+	
 	gem "rubocop"
+	gem "rubocop-md"
+	gem "rubocop-socketry"
 	
 	gem "traces"
 	gem "sus-fixtures-async"
